rd_kafka_queue_get_background method
@returns a reference to the background thread queue, or NULL if the background queue is not enabled.
The background thread queue provides the application with an automatically polled queue that triggers the event callback in a background thread, this background thread is completely managed by librdkafka.
The background thread queue is automatically created if a generic event handler callback is configured with rd_kafka_conf_set_background_event_cb() or if rd_kafka_queue_get_background() is called.
The background queue is polled and served by librdkafka and MUST NOT be polled, forwarded, or otherwise managed by the application, it may only be used as the destination queue passed to queue-enabled APIs, such as the Admin API.
Use rd_kafka_queue_destroy() to loose the reference.
@warning The background queue MUST NOT be read from (polled, consumed, etc), or forwarded from.
Implementation
ffi.Pointer<rd_kafka_queue_t> rd_kafka_queue_get_background(
ffi.Pointer<rd_kafka_t> rk,
) {
return _rd_kafka_queue_get_background(rk);
}