UnnamedUnion1 class final
Value union, see RD_KAFKA_V_.. macros for which field to use.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the UnionAddress extension
The memory address of the underlying data.no setter -
cstr
↔ Pointer<
Char> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- header ↔ UnnamedStruct2
-
getter/setter pair
-
headers
↔ Pointer<
rd_kafka_headers_t> -
getter/setter pair
- i ↔ int
-
getter/setter pair
- i32 ↔ int
-
getter/setter pair
- i64 ↔ int
-
getter/setter pair
- mem ↔ UnnamedStruct1
-
getter/setter pair
-
ptr
↔ Pointer<
Void> -
getter/setter pair
-
rkt
↔ Pointer<
rd_kafka_topic_t> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited