rd_kafka_IsolationLevel_t enum

@enum rd_kafka_IsolationLevel_t

@brief IsolationLevel enum name for use with rd_kafka_AdminOptions_new()

@sa rd_kafka_AdminOptions_new()

Inheritance
Available extensions

Values

RD_KAFKA_ISOLATION_LEVEL_READ_UNCOMMITTED → const rd_kafka_IsolationLevel_t
const rd_kafka_IsolationLevel_t(0)
RD_KAFKA_ISOLATION_LEVEL_READ_COMMITTED → const rd_kafka_IsolationLevel_t
const rd_kafka_IsolationLevel_t(1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) rd_kafka_IsolationLevel_t

Constants

values → const List<rd_kafka_IsolationLevel_t>
A constant List of the values in this enum, in order of their declaration.