rd_kafka_message_t typedef

rd_kafka_message_t = rd_kafka_message_s

@brief A Kafka message as returned by the \c rd_kafka_consume*() family of functions as well as provided to the Producer \c dr_msg_cb().

For the consumer this object has two purposes:

  • provide the application with a consumed message. (\c err == 0)
  • report per-topic+partition consumer errors (\c err != 0)

The application must check \c err to decide what action to take.

When the application is finished with a message it must call rd_kafka_message_destroy() unless otherwise noted.

Implementation

typedef rd_kafka_message_t = rd_kafka_message_s;