rd_kafka_metadata class final

@brief Metadata container

Inheritance
Implemented types
Available extensions

Constructors

rd_kafka_metadata()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
broker_cnt int
< Number of brokers in \p brokers
getter/setter pair
brokers Pointer<rd_kafka_metadata_broker>
< Brokers
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
orig_broker_id int
< Broker originating this metadata
getter/setter pair
orig_broker_name Pointer<Char>
< Name of originating broker
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic_cnt int
< Number of topics in \p topics
getter/setter pair
topics Pointer<rd_kafka_metadata_topic>
< Topics
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited