rd_kafka_metadata_topic class final

@brief Topic information

Inheritance
Implemented types
Available extensions

Constructors

rd_kafka_metadata_topic()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
err rd_kafka_resp_err_t
no setter
errAsInt int
< Topic error reported by broker
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
partition_cnt int
< Number of partitions in \p partitions
getter/setter pair
partitions Pointer<rd_kafka_metadata_partition>
< Partitions
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic Pointer<Char>
< Topic name
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited