rd_kafka_vu_s class final

@brief VTYPE + argument container for use with rd_kafka_produce_va()

See RD_KAFKA_V_..() macros below for which union field corresponds to which RD_KAFKA_VTYPE_...

Inheritance
Implemented types
Available extensions

Constructors

rd_kafka_vu_s()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
u UnnamedUnion1
getter/setter pair
vtype rd_kafka_vtype_t
no setter
vtypeAsInt int
< RD_KAFKA_VTYPE_..
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited