rd_kafka_queue_yield method
@brief Cancels the current rd_kafka_queue_poll() on \p rkqu.
An application may use this from another thread to force an immediate return to the calling code (caller of rd_kafka_queue_poll()). Must not be used from signal handlers since that may cause deadlocks.
Implementation
void rd_kafka_queue_yield(ffi.Pointer<rd_kafka_queue_t> rkqu) {
return _rd_kafka_queue_yield(rkqu);
}