rd_kafka_ConfigSource_t enum
@enum rd_kafka_ConfigSource_t
@brief Apache Kafka config sources.
@remark These entities relate to the cluster, not the local client.
@sa rd_kafka_conf_set(), et.al. for local client configuration.
Values
- RD_KAFKA_CONFIG_SOURCE_UNKNOWN_CONFIG → const rd_kafka_ConfigSource_t
-
Source unknown, e.g., in the ConfigEntry used for alter requests where source is not set
const rd_kafka_ConfigSource_t(0) - RD_KAFKA_CONFIG_SOURCE_DYNAMIC_TOPIC_CONFIG → const rd_kafka_ConfigSource_t
-
Dynamic topic config that is configured for a specific topic
const rd_kafka_ConfigSource_t(1) - RD_KAFKA_CONFIG_SOURCE_DYNAMIC_BROKER_CONFIG → const rd_kafka_ConfigSource_t
-
Dynamic broker config that is configured for a specific broker
const rd_kafka_ConfigSource_t(2) - RD_KAFKA_CONFIG_SOURCE_DYNAMIC_DEFAULT_BROKER_CONFIG → const rd_kafka_ConfigSource_t
-
Dynamic broker config that is configured as default for all brokers in the cluster
const rd_kafka_ConfigSource_t(3) - RD_KAFKA_CONFIG_SOURCE_STATIC_BROKER_CONFIG → const rd_kafka_ConfigSource_t
-
Static broker config provided as broker properties at startup (e.g. from server.properties file)
const rd_kafka_ConfigSource_t(4) - RD_KAFKA_CONFIG_SOURCE_DEFAULT_CONFIG → const rd_kafka_ConfigSource_t
-
Built-in default configuration for configs that have a default value
const rd_kafka_ConfigSource_t(5) - RD_KAFKA_CONFIG_SOURCE__CNT → const rd_kafka_ConfigSource_t
-
Number of source types defined
const rd_kafka_ConfigSource_t(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → rd_kafka_ConfigSource_t
Constants
-
values
→ const List<
rd_kafka_ConfigSource_t> - A constant List of the values in this enum, in order of their declaration.