rd_kafka_interceptor_f_on_commit_t typedef
rd_kafka_interceptor_f_on_commit_t = NativeFunction<Int Function(Pointer<rd_kafka_t> rk, Pointer<rd_kafka_topic_partition_list_t> offsets, Int err, Pointer<Void> ic_opaque)>
@brief on_commit() is called on completed or failed offset commit. It is called from internal librdkafka threads.
@param rk The client instance. @param offsets List of topic+partition+offset+error that were committed. The error message of each partition should be checked for error. @param err The commit error, if any. @param ic_opaque The interceptor's opaque pointer specified in ..add..().
@remark This interceptor is only used by consumer instances.
@warning The on_commit() interceptor is called from internal librdkafka threads. An on_commit() interceptor MUST NOT call any librdkafka API's associated with the \p rk, or perform any blocking or prolonged work.
@returns an error code on failure, the error is logged but otherwise ignored.
Implementation
typedef rd_kafka_interceptor_f_on_commit_t =
ffi.NativeFunction<
ffi.Int Function(
ffi.Pointer<rd_kafka_t> rk,
ffi.Pointer<rd_kafka_topic_partition_list_t> offsets,
ffi.Int err,
ffi.Pointer<ffi.Void> ic_opaque,
)
>;